@@ -14,9 +14,12 @@ import numpy as np
 import math
 import os
 
-def collect_information(bin_precision,bin_width):
+def collect_information(bin_precision,bin_width,percent):
 	folder='mass_align_all'
 	
+	fraction_1=os.listdir('pre_result')[0]
+	total_sample_number=len(os.listdir('pre_result/'+fraction_1))
+	
 	result_folder='mass_align_all_information'
 	if not os.path.exists(result_folder):
 		os.mkdir(result_folder)
@@ -45,6 +48,8 @@ def collect_information(bin_precision,bin_width):
 		file_df=file_df[file_df['status']=='use']
 		grouped=file_df.groupby(['group'])
 		for name,group in grouped:
+			if len(group)<total_sample_number*percent:
+				continue
 			group_central=group[group['Tmass']==window_central]
 			if len(group_central)<len(group)/2:
 				continue
